@@ -4,7 +4,7 @@
 
 ZIP=/tmp/pango-1.10.0-`date +%Y%m%d`.zip
 DEVZIP=/tmp/pango-dev-1.10.0-`date +%Y%m%d`.zip
-cd /opt/rendering
+cd /opt/head
 
 rm $ZIP
 zip $ZIP -@ <<EOF
